@@ -18,8 +18,8 @@ __contact__ = "Kevin Carter"
 __email__ = "kevin.carter@rackspace.com"
 __copyright__ = "2013 All Rights Reserved"
 __date__ = "2013-23-03"
-__version__ = "0.003"
-__status__ = "Seems to Work"
+__version__ = "0.004"
+__status__ = "Working"
 __appname__ = "xenosimager"
 __license__ = "Apache2.0"
 __description__ = ("Create an image of a instance from data obtained from"
